@@ -1,12 +1,15 @@
 package Text::Table::Tiny;
-$Text::Table::Tiny::VERSION = '1.00';
-use 5.010;
+$Text::Table::Tiny::VERSION = '1.01_01'; # TRIAL
+
+$Text::Table::Tiny::VERSION = '1.0101';use 5.010;
 use strict;
 use warnings;
 use utf8;
 use parent 'Exporter';
-use Carp         qw/ croak /;
-use Ref::Util    qw/ is_arrayref is_ref /;
+use Carp                    qw/ croak /;
+use Ref::Util         0.202 qw/ is_arrayref /;
+use String::TtyLength 0.02  qw/ tty_width /;
+
 our @EXPORT_OK = qw/ generate_table /;
 
 # Legacy package globals, that can be used to customise the look.
@@ -18,6 +21,17 @@ our $CORNER_MARKER        = '+';
 our $HEADER_ROW_SEPARATOR = '=';
 our $HEADER_CORNER_MARKER = 'O';
 
+my %arguments = (
+    rows => "the rows, including a possible header row, of the table",
+    header_row => "if true, indicates that the first row is a header row",
+    separate_rows => "if true, a separate rule will be drawn between each row",
+    top_and_tail => "if true, miss out top and bottom edges of table",
+    align => "either single alignment, or an array per of alignments per col",
+    style => "styling of table, one of classic, boxrule, or norule",
+    indent => "indent every row of the table a certain number of spaces",
+    compact => "narrow columns (no space either side of content)",
+);
+
 my %charsets = (
     classic => { TLC => '+', TT => '+', TRC => '+', HR => '-', VR => '|', FHR => '=', LT => '+', RT => '+', FLT => 'O', FRT => 'O', HC => '+', FHC => 'O', BLC => '+', BT => '+', BRC => '+' },
     boxrule => { TLC => '┌', TT => '┬', TRC => '┐', HR => '─', VR => '│', FHR => '═', LT => '├', RT => '┤', FLT => '╞', FRT => '╡', HC => '┼', FHC => '╪', BLC => '└', BT => '┴', BRC => '┘' },
@@ -27,6 +41,11 @@ my %charsets = (
 sub generate_table
 {
     my %param   = @_;
+
+    foreach my $arg (keys %param) {
+        croak "unknown argument '$arg'" if not exists $arguments{$arg};
+    }
+
     my $rows    = $param{rows} or croak "you must pass the 'rows' argument!";
     my @rows    = @$rows;
     my @widths  = _calculate_widths($rows);
@@ -78,16 +97,6 @@ sub _top_border
 
     return '' if $param->{top_and_tail};
     return _rule_row($param, $widths, $char->{TLC}, $char->{HR}, $char->{TT}, $char->{TRC});
-
-    return '' if $param->{top_and_tail};
-    my $pad = $param->{compact} ? '' : $char->{HR};
-
-    return $param->{indent}
-           .$char->{TLC}
-           .join($char->{TT}, map { $pad.($char->{HR} x $_).$pad } @$widths)
-           .$char->{TRC}
-           ."\n"
-           ;
 }
 
 sub _bottom_border
@@ -157,17 +166,17 @@ sub _format_column
     my $pad = $param->{compact} ? '' : ' ';
 
     if ($align eq 'r' || $align eq 'right') {
-        return $pad.' ' x ($width - tty_length($text)).$text.$pad;
+        return $pad.' ' x ($width - tty_width($text)).$text.$pad;
     }
     elsif ($align eq 'c' || $align eq 'center' || $align eq 'centre') {
-        my $total_spaces = $width - tty_length($text);
+        my $total_spaces = $width - tty_width($text);
         my $left_spaces  = int($total_spaces / 2);
         my $right_spaces = $left_spaces;
         $right_spaces++ if $total_spaces % 2 == 1;
         return $pad.(' ' x $left_spaces).$text.(' ' x $right_spaces).$pad;
     }
     else {
-        return $pad.$text.' ' x ($width - tty_length($text)).$pad;
+        return $pad.$text.' ' x ($width - tty_width($text)).$pad;
     }
 }
 
@@ -179,20 +188,16 @@ sub _calculate_widths
         my @columns = @$row;
         for (my $i = 0; $i < @columns; $i++) {
             next unless defined($columns[$i]);
-            $widths[$i] = tty_length($columns[$i]) if !defined($widths[$i])
-                                                   || tty_length($columns[$i]) > $widths[$i];
+
+            my $width = tty_width($columns[$i]);
+
+            $widths[$i] = $width if !defined($widths[$i])
+                                 || $width > $widths[$i];
         }
     }
     return @widths;
 }
 
-sub tty_length
-{
-    my $string = shift;
-    $string =~ s/\e\[[0-9]+(;[0-9]+)?[ABCDEFGHJKSTfmin]//msg;
-    return length($string);
-}
-
 # Back-compat: 'table' is an alias for 'generate_table', but isn't exported
 *table = \&generate_table;
 
@@ -257,6 +262,9 @@ The only required argument is B<rows>.
 Where arguments were not supported in the original release,
 the first supporting version is noted.
 
+If you pass an unknown argument,
+C<generate_table> will die with an error message.
+
 =over 4
 
 
